@@ -1,7 +1,3 @@
-# $Id: /mirror/coderepos/lang/perl/Cache-Memcached-libmemcached/trunk/lib/Cache/Memcached/libmemcached.pm 102844 2009-03-27T00:36:19.640128Z daisuke  $
-#
-# Copyright (c) 2008 Daisuke Maki <daisuke@endeworks.jp>
-# All rights reserved.
 
 package Cache::Memcached::libmemcached;
 use strict;
@@ -11,7 +7,7 @@ use Carp qw(croak);
 use Scalar::Util qw(weaken);
 use Storable ();
 
-our $VERSION = '0.02009';
+our $VERSION = '0.02010';
 
 use constant HAVE_ZLIB    => eval { require Compress::Zlib } && !$@;
 use constant F_STORABLE   => 1;
@@ -110,9 +106,10 @@ sub new
     );
 
     # behavior options
-    $self->set_no_block( $args->{no_block} ) if exists $args->{no_block};
-    $self->set_hashing_algorithm( $args->{hashing_algorithm} ) if exists $args->{hashing_algorithm};
-    $self->set_distribution_method( $args->{distribution_method} ) if exists $args->{distribution_method};
+    foreach my $option qw(no_block hashing_algorithm distribution_method binary_protocol) {
+        my $method = "set_$option";
+        $self->$method( $args->{$option} ) if exists $args->{$option};
+    }
 
     $self->{namespace} = $args->{namespace} || '';
 
@@ -133,7 +130,9 @@ sub server_add
     my $self = shift;
     my $server = shift;
 
-    # check for existance of : 
+    if (! defined $server) {
+        Carp::confess("server is not defined");
+    }
     if ($server =~ /^([^:]+):([^:]+)$/) {
         my ($hostname, $port) = ($1, $2);
         $self->memcached_server_add($hostname, $port );
@@ -228,11 +227,14 @@ sub flush_all
 
 *remove = \&delete;
 
-sub disconnect_all
-{
+sub disconnect_all {
     $_[0]->memcached_quit();
 }
 
+sub version {
+    $_[0]->memcached_version();
+}
+
 sub stats
 {
     my %h;
@@ -266,7 +268,7 @@ sub stats
 
 BEGIN
 {
-    my @boolean_behavior = qw( no_block );
+    my @boolean_behavior = qw( no_block binary_protocol );
     my %behavior = (
         distribution_method => 'distribution',
         hashing_algorithm   => 'hash'
@@ -652,6 +654,13 @@ Get the hashing algorithm used.
 
 Enable/disable CAS support.
 
+=head1 set_binary_protocol
+
+  $memd->set_binary_protocol( 1 );
+  $binary = $memd->is_binary_protocol();
+
+Enable/disable binary protocol
+
 =head1 OPTIMIZE FLAG
 
 There's an EXPERIMENTAL optimization available for some corner cases, where
